.. _python_metrics:

Metrics (Experimental)
======================

Here we describe the available metrics in Rubrix:

- Text classification: Metrics for text classification
- Token classification: Metrics for token classification

Text classification
-------------------

.. automodule:: rubrix.metrics.text_classification.metrics
   :members:

Token classification
--------------------

.. automodule:: rubrix.metrics.token_classification.metrics
   :members:


